@@ -24,23 +24,20 @@ class SendCoTAbstractController(ABC):
                 logger.error('an undocumented CoT has been sent returning the error ' + str(e) + ' please post this as an issue on the FTS git so we can document and fix it')
                 return 1
             else:
-                logger.error('there has been an exception in the creation of the model object ' + str(e))
+                logger.warning('there has been an exception in the creation of the model object ' + str(e))
                 return -1
 
-
-        except Exception as e:
-            logger.error('there has been an exception in the creation of a model object ' + str(e))
         try:
             object.xmlString = self.create_xml_string(object.modelObject)
         except Exception as e:
-            logger.error('there has been an exception in the creation of a xmlString ' + str(e))
+            logger.warning('there has been an exception in the creation of a xmlString ' + str(e))
         try:
             if addToDB == True:
                 RawCoT.dbController.create_CoT(object.modelObject)
             else:
                 pass
         except Exception as e:
-            logger.error('there has been an exception in the creation of a database instance of this object ' + str(e))
+            logger.warning('there has been an exception in the creation of a database instance of this object ' + str(e))
 
         self.setObject(object)
 
